ExecutionPlan

Struct ExecutionPlan 

pub struct ExecutionPlan {
    pub blueprint: OsBlueprint,
    pub target: Target,
    pub toolchain: ToolchainSpec,
    pub build: CommandSpec,
    pub run: Option<CommandSpec>,
    pub package: Option<CommandSpec>,
}
A deterministic, side-effect free description of how a build could be executed.

The suite intentionally separates:

  • Planning: OsBuilder => BuildPlan.
  • Execution intent: ExecutionPlanner => ExecutionPlan.

The execution plan is designed for host tooling and CI systems. It does not perform any IO on its own.

Fields

blueprint: OsBlueprint

Original blueprint.

target: Target

Target derived from planning.

toolchain: ToolchainSpec

Suggested Rust toolchain/channel.

build: CommandSpec

Suggested build command.

run: Option<CommandSpec>

Optional run command (e.g. QEMU).

package: Option<CommandSpec>

Optional packaging command.