pub struct ExecutionPlan {
pub blueprint: OsBlueprint,
pub target: Target,
pub toolchain: ToolchainSpec,
pub build: CommandSpec,
pub run: Option<CommandSpec>,
pub package: Option<CommandSpec>,
}Expand description
A deterministic, side-effect free description of how a build could be executed.
The suite intentionally separates:
- Planning:
OsBuilder=>BuildPlan. - Execution intent:
ExecutionPlanner=>ExecutionPlan.
The execution plan is designed for host tooling and CI systems. It does not perform any IO on its own.
Fields
blueprint: OsBlueprintOriginal blueprint.
target: TargetTarget derived from planning.
toolchain: ToolchainSpecSuggested Rust toolchain/channel.
build: CommandSpecSuggested build command.
run: Option<CommandSpec>Optional run command (e.g. QEMU).
package: Option<CommandSpec>Optional packaging command.